﻿"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IncompatibleProviderError = exports.InvalidProviderHookError = exports.InvalidProviderSchemaTransformerError = exports.EmptyRouteFileError = exports.InvalidProviderGenericTypeError = exports.RouteParameterMultipleErrors = exports.RouteMapperNotExportedError = exports.RouteOptionsAlreadyDefinedError = exports.ReturnTypeError = exports.WronglyTypedProviderError = exports.ProviderResolverNotFound = exports.EmptyJsdocError = exports.UntypedProviderError = exports.NoProviderExportedError = exports.SourceFileNotFoundError = exports.CannotCreateNodeTypeError = exports.CannotResolveParameterNameError = exports.ParameterResolverNotFoundError = exports.RouteResolverNotFoundError = void 0;
const base_1 = require("./base");
class RouteResolverNotFoundError extends base_1.KitaError {
    type = 'parser';
    constructor(node) {
        super({
            code: 300,
            messageText: 'Could not find a route resolver for this function.',
            node
        });
    }
}
exports.RouteResolverNotFoundError = RouteResolverNotFoundError;
class ParameterResolverNotFoundError extends base_1.KitaError {
    type = 'parser';
    constructor(node) {
        super({
            code: 301,
            messageText: 'This parameter type does not have a registered resolved. Did you forget to wrap it into a Body<>, Query<>, etc.?',
            node
        });
    }
}
exports.ParameterResolverNotFoundError = ParameterResolverNotFoundError;
class CannotResolveParameterNameError extends base_1.KitaError {
    type = 'parser';
    constructor(node) {
        super({
            code: 302,
            messageText: 'Could not resolve the parameter name because you are using a destructuring pattern and not providing a name through a string literal',
            node
        });
    }
}
exports.CannotResolveParameterNameError = CannotResolveParameterNameError;
class CannotCreateNodeTypeError extends base_1.KitaError {
    type = 'parser';
    constructor(node, error) {
        super({
            code: 303,
            messageText: `Could not create type node for specified type: ${String(error)}`,
            node
        });
    }
}
exports.CannotCreateNodeTypeError = CannotCreateNodeTypeError;
class SourceFileNotFoundError extends base_1.KitaError {
    path;
    type = 'parser';
    constructor(path) {
        super({
            code: 304,
            messageText: `Could not find source file: ${path}`
        });
        this.path = path;
    }
}
exports.SourceFileNotFoundError = SourceFileNotFoundError;
class NoProviderExportedError extends base_1.KitaError {
    type = 'parser';
    constructor(node) {
        super({
            code: 305,
            messageText: 'No default function exported at this path. You must export a default function on every file matching the provider glob.',
            node
        });
    }
}
exports.NoProviderExportedError = NoProviderExportedError;
class UntypedProviderError extends base_1.KitaError {
    type = 'parser';
    constructor(node) {
        super({
            code: 306,
            messageText: 'The provider default export needs to have a explicit return type declared.',
            node
        });
    }
}
exports.UntypedProviderError = UntypedProviderError;
class EmptyJsdocError extends base_1.KitaError {
    type = 'parser';
    constructor(node) {
        super({
            code: 307,
            messageText: 'You forgot to provide a value for this JSDoc tag.',
            node
        });
    }
}
exports.EmptyJsdocError = EmptyJsdocError;
class ProviderResolverNotFound extends base_1.KitaError {
    type = 'parser';
    constructor(node) {
        super({
            code: 308,
            messageText: 'Could not find a provider resolver for this function.',
            node
        });
    }
}
exports.ProviderResolverNotFound = ProviderResolverNotFound;
class WronglyTypedProviderError extends base_1.KitaError {
    type = 'parser';
    constructor(node) {
        super({
            code: 309,
            messageText: 'The provider function resolver return type must be a type reference, no other types are allowed.',
            node
        });
    }
}
exports.WronglyTypedProviderError = WronglyTypedProviderError;
class ReturnTypeError extends base_1.KitaError {
    error;
    type = 'parser';
    constructor(node, error) {
        super({
            code: 310,
            messageText: `Could not resolve return type of provided function: ${String(error)}`,
            node
        });
        this.error = error;
    }
}
exports.ReturnTypeError = ReturnTypeError;
class RouteOptionsAlreadyDefinedError extends base_1.KitaError {
    type = 'parser';
    constructor(node) {
        super({
            code: 311,
            messageText: 'This route already has defined options.',
            node
        });
    }
}
exports.RouteOptionsAlreadyDefinedError = RouteOptionsAlreadyDefinedError;
class RouteMapperNotExportedError extends base_1.KitaError {
    type = 'parser';
    constructor(node) {
        super({
            code: 312,
            messageText: 'You are using a route mapper inside a `this: Use<>` parameter, but the mapper is not exported in the same file.',
            node
        });
    }
}
exports.RouteMapperNotExportedError = RouteMapperNotExportedError;
class RouteParameterMultipleErrors extends base_1.KitaError {
    children;
    type = 'parser';
    constructor(node, children) {
        super({
            code: 313,
            messageText: 'Multiple errors were found while parsing this route: \n' + children.map((e) => e.message).join('\n'),
            node,
            relatedInformation: children.map((e) => e.diagnostic)
        });
        this.children = children;
    }
}
exports.RouteParameterMultipleErrors = RouteParameterMultipleErrors;
class InvalidProviderGenericTypeError extends base_1.KitaError {
    type = 'parser';
    constructor(node) {
        super({
            code: 314,
            messageText: 'You can only use literal types as generic types for providers, such as `1`, `true` and `"string"`',
            node
        });
    }
}
exports.InvalidProviderGenericTypeError = InvalidProviderGenericTypeError;
class EmptyRouteFileError extends base_1.KitaError {
    node;
    constructor(node) {
        super({
            code: 315,
            messageText: 'You cannot have empty route files inside a route directory. Please add at least one route.',
            node
        });
        this.node = node;
    }
}
exports.EmptyRouteFileError = EmptyRouteFileError;
class InvalidProviderSchemaTransformerError extends base_1.KitaError {
    msg;
    type = 'parser';
    constructor(node, msg) {
        super({
            code: 316,
            messageText: `Invalid schemaTransformer: ${msg}`,
            node
        });
        this.msg = msg;
    }
}
exports.InvalidProviderSchemaTransformerError = InvalidProviderSchemaTransformerError;
class InvalidProviderHookError extends base_1.KitaError {
    msg;
    type = 'parser';
    constructor(node, msg) {
        super({
            code: 317,
            messageText: `Invalid provider hook: ${msg}`,
            node
        });
        this.msg = msg;
    }
}
exports.InvalidProviderHookError = InvalidProviderHookError;
class IncompatibleProviderError extends base_1.KitaError {
    children;
    type = 'parser';
    constructor(node, children) {
        super({
            code: 318,
            messageText: 'This provider cannot be used here: \n' + children.map((e) => e.message).join('\n'),
            node,
            relatedInformation: children.map((e) => e.diagnostic)
        });
        this.children = children;
    }
}
exports.IncompatibleProviderError = IncompatibleProviderError;
//# sourceMappingURL=parser.js.map