﻿"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RouteWithoutReturnError = exports.DefaultExportedRoute = exports.FileInGetRequestError = exports.UnknownHttpJsdocError = exports.UnknownHttpError = exports.InvalidHtmlRoute = exports.QueryMixError = exports.JsdocAlreadyDefinedError = exports.DuplicateProviderTypeError = exports.DuplicateOperationIdError = exports.InvalidParameterUsageError = exports.ParameterConflictError = exports.BodyInGetRequestError = exports.MultipleDefinitionsError = void 0;
const tslib_1 = require("tslib");
const typescript_1 = tslib_1.__importDefault(require("typescript"));
const base_1 = require("./base");
class MultipleDefinitionsError extends base_1.KitaError {
    typename;
    type = 'validator';
    constructor(typename) {
        super({
            code: 400,
            messageText: 'Provided typename has multiple definitions.'
        });
        this.typename = typename;
    }
}
exports.MultipleDefinitionsError = MultipleDefinitionsError;
class BodyInGetRequestError extends base_1.KitaError {
    type = 'validator';
    constructor(node) {
        super({
            code: 401,
            messageText: 'You cannot use any Body dependent code in a GET request.',
            node
        });
    }
}
exports.BodyInGetRequestError = BodyInGetRequestError;
class ParameterConflictError extends base_1.KitaError {
    existing;
    attempt;
    type = 'validator';
    constructor(existing, attempt, node) {
        super({
            code: 402,
            messageText: `You cannot use ${attempt} when ${existing} is already used in the same route.`,
            node
        });
        this.existing = existing;
        this.attempt = attempt;
    }
}
exports.ParameterConflictError = ParameterConflictError;
class InvalidParameterUsageError extends base_1.KitaError {
    usage;
    type = 'validator';
    constructor(usage, node) {
        super({
            code: 403,
            messageText: `Invalid parameter usage: ${usage}`,
            node
        });
        this.usage = usage;
    }
}
exports.InvalidParameterUsageError = InvalidParameterUsageError;
class DuplicateOperationIdError extends base_1.KitaError {
    operationId;
    node;
    type = 'validator';
    constructor(operationId, node) {
        super({
            code: 404,
            node,
            messageText: `Duplicate operationId: ${operationId}`
        });
        this.operationId = operationId;
        this.node = node;
    }
}
exports.DuplicateOperationIdError = DuplicateOperationIdError;
class DuplicateProviderTypeError extends base_1.KitaError {
    provider;
    pathA;
    pathB;
    type = 'validator';
    constructor(provider, pathA, pathB) {
        super({
            code: 405,
            messageText: `Duplicate provider: ${provider}`,
            relatedInformation: [
                base_1.KitaError.createDiagnostic({
                    file: typescript_1.default.createSourceFile(pathA, '', typescript_1.default.ScriptTarget.ES2015),
                    code: 405,
                    messageText: `Provider 1: ${pathA}`
                }),
                base_1.KitaError.createDiagnostic({
                    file: typescript_1.default.createSourceFile(pathB, '', typescript_1.default.ScriptTarget.ES2015),
                    code: 405,
                    messageText: `Provider 2: ${pathB}`
                })
            ]
        });
        this.provider = provider;
        this.pathA = pathA;
        this.pathB = pathB;
    }
}
exports.DuplicateProviderTypeError = DuplicateProviderTypeError;
class JsdocAlreadyDefinedError extends base_1.KitaError {
    type = 'validator';
    constructor(node) {
        super({
            code: 406,
            messageText: 'You are trying to use a JSDoc tag on a node that already had this value explicit set.',
            node
        });
    }
}
exports.JsdocAlreadyDefinedError = JsdocAlreadyDefinedError;
class QueryMixError extends base_1.KitaError {
    type = 'validator';
    constructor(node) {
        super({
            code: 407,
            messageText: 'You are mixing primitive and deep query types inside the same route.',
            node
        });
    }
}
exports.QueryMixError = QueryMixError;
class InvalidHtmlRoute extends base_1.KitaError {
    primitive;
    type = 'validator';
    constructor(node, primitive) {
        super({
            code: 408,
            messageText: 'You cannot use a non-string return type in a HTML route.',
            node
        });
        this.primitive = primitive;
    }
}
exports.InvalidHtmlRoute = InvalidHtmlRoute;
class UnknownHttpError extends base_1.KitaError {
    type = 'validator';
    constructor(node) {
        super({
            code: 409,
            messageText: 'Could not resolve a http status code for this error, are you using a method exposed by @fastify/sensible?',
            node
        });
    }
}
exports.UnknownHttpError = UnknownHttpError;
class UnknownHttpJsdocError extends base_1.KitaError {
    type = 'validator';
    constructor(node) {
        super({
            code: 410,
            messageText: 'Could not resolve a http status code for this error, please only use @throws <number>',
            node
        });
    }
}
exports.UnknownHttpJsdocError = UnknownHttpJsdocError;
class FileInGetRequestError extends base_1.KitaError {
    type = 'validator';
    constructor(node) {
        super({
            code: 411,
            messageText: 'You cannot use any File and SavedFile in a GET request.',
            node
        });
    }
}
exports.FileInGetRequestError = FileInGetRequestError;
class DefaultExportedRoute extends base_1.KitaError {
    type = 'validator';
    constructor(node) {
        super({
            code: 412,
            messageText: 'You cannot use default exported routes. Please remove the `default` modifier',
            node
        });
    }
}
exports.DefaultExportedRoute = DefaultExportedRoute;
class RouteWithoutReturnError extends base_1.KitaError {
    type = 'validator';
    constructor(node) {
        super({
            code: 413,
            messageText: 'You cannot have a route that returns `undefined`, please use other value such as `true`, `""` or `null`.',
            node
        });
    }
}
exports.RouteWithoutReturnError = RouteWithoutReturnError;
//# sourceMappingURL=validator.js.map