﻿"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChainParser = void 0;
const util_1 = require("../util");
class ChainParser {
    /** All the parsers in this chain. */
    parsers = new Set();
    /** A simple node cache to increase the performance at parse() when getting the correct parser */
    cache = new WeakMap();
    /** Adds a parser to this chain. */
    add(parser) {
        this.parsers.add(parser);
        return this;
    }
    /** Checks if the given node is supported by any of the parsers and caches the result. */
    async supports(node) {
        // Checks if the cache already has the node
        if (this.cache.get(node)) {
            return true;
        }
        // Asynchronously checks if any of the parsers supports the node
        const parser = await (0, util_1.predicateRace)(this.parsers, this.parsers.size, 'supports', node);
        // No parser was found
        if (!parser) {
            return false;
        }
        this.cache.set(node, parser);
        return true;
    }
}
exports.ChainParser = ChainParser;
//# sourceMappingURL=chain.js.map