﻿"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isPromiseLike = exports.predicateRace = void 0;
/** Resolves the first predicate that returns true. Otherwise, returns literal `false`. */
function predicateRace(resolvers, maxTries, callKey, ...args) {
    let resolved = 0;
    let promise;
    return new Promise(function predicatePromise(resolve, reject) {
        for (const resolver of resolvers) {
            promise = resolver[callKey](...args);
            if (!(promise instanceof Promise)) {
                promise = Promise.resolve(promise);
            }
            promise.then(function resolvePredicate(result) {
                // Promise was resolved before
                if (resolved >= maxTries) {
                    return;
                }
                // We got a result
                if (result) {
                    // Marks all other resolvers as resolved (so we can ignore their results)
                    resolved = maxTries;
                    // Resolves current promise
                    return resolve(resolver);
                }
                // Marks this resolver as resolved
                resolved++;
                // If all resolvers have been resolved, we can resolve this promise
                // with false
                if (resolved >= maxTries) {
                    return resolve(false);
                }
            }, function handlePredicateError(error) {
                // Marks all other resolvers as resolved (so we can ignore their results)
                resolved = maxTries;
                // Reject current promise
                return reject(error);
            });
        }
    });
}
exports.predicateRace = predicateRace;
/**
 * Fast instanceof check for promises. This is faster than `value instanceof Promise` because it does not need to
 * traverse the prototype chain.
 */
function isPromiseLike(value) {
    //@ts-expect-error - We are checking for the existence of the `then` method
    return !!value && typeof value.then === 'function';
}
exports.isPromiseLike = isPromiseLike;
//# sourceMappingURL=promises.js.map